import 'package:flx_id_binder/flx_id_binder.dart';
import 'package:get/get.dart';

class OAuthBinder extends ApiBinderBase {
  final _storage = Get.find<ApiStorage>();

  Future<TokenModel> signIn({
    required String? email,
    required String? password,
    required String? appId,
    required String? appSecret,
    required String? deviceFingerprint,
    required List<AuthPermission>? permissions,
  }) async {
    return await errorHandler.handle(() async {
      var result = await requestHandler.handlePost(
        "oauth",
        "signIn",
        body: {
          "email": email,
          "password": password,
          "applicationIdentificator": appId,
          "applicationSecret": appSecret,
          "deviceFingerprint": deviceFingerprint,
          "requestedPermissions": permissions!
              .map((e) => AuthPermissionConverter.fromEnum(e))
              .toList(),
        },
      );

      return TokenModel.fromJson(result!);
    });
  }

  Future<TokenModel> updateAccess({
    required String? refreshToken,
    required String? deviceFingerprint,
  }) async {
    return await errorHandler.handle(() async {
      var result = await requestHandler.handlePost(
        "oauth",
        "updateAccess",
        body: {
          "refreshToken": refreshToken,
          "deviceFingerprint": deviceFingerprint,
        },
      );

      return TokenModel.fromJson(result!);
    });
  }

  Future<void> signUp({
    required String? firstName,
    required String? lastName,
    required String? nickname,
    required String? email,
    required String? password,
  }) async {
    await errorHandler.handle(() async {
      await requestHandler.handlePost(
        "oauth",
        "signUp",
        body: {
          "firstName": firstName,
          "lastName": lastName,
          "nickname": nickname,
          "email": email,
          "password": password,
        },
      );
    });
  }

  Future<void> signOut() async {
    await errorHandler.handle(() async {
      await requestHandler.handlePost(
        "oauth",
        "signOut",
        headers: {
          "Authorization": "Bearer ${_storage.accessToken!}",
        },
      );
    });
  }

  Future<void> signOutAll() async {
    await errorHandler.handle(() async {
      await requestHandler.handlePost(
        "oauth",
        "signOutAll",
        headers: {
          "Authorization": "Bearer ${_storage.accessToken!}",
        },
      );
    });
  }
}
