import 'package:dio/dio.dart';
import 'package:get/get.dart';

class ApiRequestHandler extends GetxService {
  final String _path = "https://api.id.flx.pub";
  final Dio _client = new Dio();

  Future<Map<dynamic, dynamic>?> handlePost(
    String controller,
    String method, {
    int? apiVersion,
    Map<String, dynamic>? queries,
    Map<String, dynamic>? headers,
    Map<String, dynamic>? body,
  }) async {
    var path =
        "$_path/${apiVersion != null ? "v1" + apiVersion.toString() + "/" + controller : controller}/$method";
    var response = await _client.post(
      path,
      queryParameters: queries,
      data: body,
      options: Options(
        headers: headers,
      ),
    );

    if (response.data is String) {
      return null;
    }

    return response.data;
  }

  Future<Map<dynamic, dynamic>?> handleGet(
    String controller,
    String method, {
    int? apiVersion,
    Map<String, dynamic>? queries,
    Map<String, dynamic>? headers,
  }) async {
    var path =
        "$_path/${apiVersion != null ? "v" + apiVersion.toString() + "/" + controller : controller}/$method";
    var response = await _client.get(
      path,
      queryParameters: queries,
      options: Options(
        headers: headers,
      ),
    );

    if (response.data is String) {
      return null;
    }

    return response.data;
  }

  Future<Map<dynamic, dynamic>?> handleDelete(
    String controller,
    String method, {
    int? apiVersion,
    Map<String, dynamic>? queries,
    Map<String, dynamic>? headers,
  }) async {
    var path =
        "$_path/${apiVersion != null ? "v" + apiVersion.toString() + "/" + controller : controller}/$method";
    var response = await _client.delete(
      path,
      queryParameters: queries,
      options: Options(
        headers: headers,
      ),
    );

    if (response.data is String) {
      return null;
    }

    return response.data;
  }
}
