import 'package:flx_id_binder/flx_id_binder.dart';
import 'package:get/get.dart';

class FlxId {
  static bool _init = false;
  static const String targetApiVer = "v1.1.0";

  static ApiStorage get apiStorage => Get.find<ApiStorage>();

  static OAuthBinder get oauth => Get.find<OAuthBinder>();
  static UserBinder get user => Get.find<UserBinder>();
  static ApplicationBinder get application => Get.find<ApplicationBinder>();
  static AchievementBinder get achievement => Get.find<AchievementBinder>();

  static Future init() async {
    if (_init) return;
    _init = true;

    try {
      await _initApiStorage();

      _initApiExceptionHander();
      _initApiResponseHander();

      _initBinders();
    } catch (e) {
      _init = false;
    }
  }

  static Future _initApiStorage() async {
    var storage = new ApiStorage();
    await storage.init();

    Get.put(storage);
  }

  static void _initApiExceptionHander() {
    var handler = new ApiExceptionHandler();

    handler.handleExceptions["ValidationException"] =
        new ValidationApiException();
    handler.handleExceptions["AuthFlxException"] = new AuthApiException();

    Get.put(handler);
  }

  static void _initApiResponseHander() {
    var handler = new ApiRequestHandler();

    Get.put(handler);
  }

  static void _initBinders() {
    Get.put(new OAuthBinder());
    Get.put(new UserBinder());
    Get.put(new ApplicationBinder());
    Get.put(new AchievementBinder());
  }

  static void auth(TokenModel? model) {
    var storage = apiStorage;
    if (model != null) {
      storage.accessToken = model.accessToken;
      storage.refreshToken = model.refreshToken;
      storage.deathDate = model.deathDate;
    } else {
      storage.accessToken = null;
      storage.refreshToken = null;
      storage.deathDate = null;
    }
  }
}
