import 'dart:convert';

import 'package:flutter_test/flutter_test.dart';
import 'package:flx_id_binder/flx_id_binder.dart';

Future<void> main() async {
  try {
    // вызывается один раз
    await FlxId.init();

    print("target api version: " + FlxId.targetApiVer);

    try {
      await FlxId.oauth.signUp(
          firstName: "roman",
          lastName: "s",
          nickname: "kunya",
          password: "nekoneko164989399felixUwU",
          email: "uwu@flx.pub");
    } on ApiException catch (e) {
      print(e.message);
    }

    print("sign in");
    // вызов метода авторизации
    var token = await FlxId.oauth.signIn(
      email: "uwu@flx.pub",
      password: "nekoneko164989399felixUwU",
      appId: "7132612a-9a9a-4b97-ab84-5d23d8bd792c",
      appSecret:
          "AplXURAwUuR66kLAqNVVW3nsvqDCGDHWieqV5TQXxemRqsTriN3SXLZJLinUMBx4",
      deviceFingerprint: "TRAP",
      permissions: [
        AuthPermission.readNames,
        AuthPermission.readApplications,
        AuthPermission.readPhotos,
        AuthPermission.manageApplications,
      ],
    );

    print("access token: " + token.accessToken);

    // нужно сохранить токен вхранилище авторизации,
    // чтобы запросы, которые требуют авторизированого пользователя,
    // могли работать
    FlxId.auth(token);

    // вызов метода, который требует авторизации
    // если пользователь будет не авторизирован, то выбьет ошибку AuthApiException
    var userInfo = await FlxId.user.getInfo();

    print("firstName: " + userInfo.firstName);
    print("lastName: " + userInfo.lastName);
    print("nickname: " + userInfo.nickname);

    var apps = await FlxId.user.getAppsIds();
    print("apps ids: " + apps.toString());

    apps.forEach((element) async {
      var app = await FlxId.application.getInfo(applicationId: element);
      print("app name: " + app.name);
      print("app trusted: " + (app.trusted ? "yes" : "not"));

      var secret = await FlxId.application.getSecret(applicationId: element);
      print("app secret: " + secret);
    });

    var picture = await FlxId.user.getPicture();
    print("user has picture: " + (picture != null ? "yes" : "not"));

    // get achivments
    var ach = await FlxId.user.getAchievementsIds();
    print("user has achs with ids: " + jsonEncode(ach));

    // выход из аккаунта
    print("sign out");
    await FlxId.oauth.signOut();
    FlxId.auth(null);
  } on ApiException catch (e) {
    print(e.message);
  }
}
